@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8:
 #
-# (C) 2006,2007,2010-2012,2015,2016 Guido Guenther <agx@sigxcpu.org>
+# (C) 2006,2007,2010-2012,2015,2016,2017 Guido Guenther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -17,7 +17,7 @@
 """handles command line and config file option parsing for the gbp commands"""
 
 from optparse import OptionParser, OptionGroup, Option, OptionValueError
-from six.moves import configparser
+import configparser
 from copy import copy
 import errno
 import os.path
@@ -101,88 +101,90 @@ class GbpOptionParser(OptionParser):
     @cvar def_config_files: config files we parse
     @type def_config_files: dict (type, path)
     """
-    defaults = {'debian-branch': 'master',
-                'upstream-branch': 'upstream',
-                'upstream-tree': 'TAG',
-                'pq-from': 'DEBIAN',
-                'pristine-tar': 'False',
-                'pristine-tar-commit': 'False',
-                'filter-pristine-tar': 'False',
-                'sign-tags': 'False',
-                'force-create': 'False',
-                'no-create-orig': 'False',
+    defaults = {'abbrev': 7,
+                'allow-unauthenticated': 'False',
+                'arch': '',
+                'author-date-is-committer-date': 'False',
+                'author-is-committer': 'False',
+                'bare': 'True',
                 'cleaner': '/bin/true',
-                'keyid': '',
-                'posttag': '',
-                'postbuild': '',
-                'prebuild': '',
-                'postclone': '',
-                'postexport': '',
-                'postimport': '',
-                'hooks': 'True',
+                'color': 'auto',
+                'color-scheme': '',
+                'commit': 'False',
+                'commit-msg': 'Update changelog for %(version)s release',
+                'component': [],
+                'compression': 'auto',
+                'compression-level': '',
+                'create-missing-branches': 'False',
+                'customizations': '',
+                'dch-opt': [],
+                'debian-branch': 'master',
                 'debian-tag': 'debian/%(version)s',
                 'debian-tag-msg': '%(pkg)s Debian release %(version)s',
-                'upstream-tag': 'upstream/%(version)s',
-                'import-msg': 'New upstream version %(version)s',
-                'commit-msg': 'Update changelog for %(version)s release',
-                'filter': [],
-                'snapshot-number': 'snapshot + 1',
-                'git-log': '--no-merges',
+                'dist': 'sid',
+                'drop': 'False',
                 'export': 'HEAD',
                 'export-dir': '',
-                'overlay': 'False',
-                'tarball-dir': '',
-                'ignore-new': 'False',
+                'filter': [],
+                'filter-pristine-tar': 'False',
+                'force-create': 'False',
+                'full': 'False',
+                'git-author': 'False',
+                'git-log': '--no-merges',
+                'hooks': 'True',
+                'id-length': '0',
                 'ignore-branch': 'False',
+                'ignore-new': 'False',
+                'ignore-regex': '',
+                'import-msg': 'New upstream version %(version)s',
+                'interactive': 'True',
+                'keyid': '',
+                'merge': 'True',
+                'merge-mode': 'auto',
                 'meta': 'True',
                 'meta-closes': 'Closes|LP',
                 'meta-closes-bugnum': r'(?:bug|issue)?\#?\s?\d+',
-                'full': 'False',
-                'id-length': '0',
-                'git-author': 'False',
-                'ignore-regex': '',
-                'compression': 'auto',
-                'compression-level': '',
-                'remote-url-pattern': 'ssh://git.debian.org/git/collab-maint/%(pkg)s.git',
                 'multimaint': 'True',
                 'multimaint-merge': 'False',
-                'pbuilder': 'False',
-                'qemubuilder': 'False',
-                'dist': 'sid',
-                'arch': '',
-                'interactive': 'True',
-                'color': 'auto',
-                'color-scheme': '',
-                'customizations': '',
-                'spawn-editor': 'release',
-                'patch-numbers': 'True',
-                'patch-num-format': '%04d-',
-                'renumber': 'False',
+                'no-create-orig': 'False',
                 'notify': 'auto',
-                'merge': 'True',
-                'merge-mode': 'auto',
-                'track': 'True',
-                'author-is-committer': 'False',
-                'author-date-is-committer-date': 'False',
-                'create-missing-branches': 'False',
-                'submodules': 'False',
-                'time-machine': 1,
+                'overlay': 'False',
+                'patch-num-format': '%04d-',
+                'patch-numbers': 'True',
+                'pbuilder': 'False',
                 'pbuilder-autoconf': 'True',
                 'pbuilder-options': '',
-                'template-dir': '',
-                'remote-config': '',
-                'allow-unauthenticated': 'False',
-                'symlink-orig': 'True',
+                'postbuild': '',
+                'postclone': '',
+                'postexport': '',
+                'postimport': '',
+                'posttag': '',
+                'pq-from': 'DEBIAN',
+                'prebuild': '',
+                'pristine-tar': 'False',
+                'pristine-tar-commit': 'False',
                 'purge': 'True',
-                'drop': 'False',
-                'commit': 'False',
-                'upstream-vcs-tag': '',
-                'rollback': 'True',
-                'component': [],
-                'bare': 'True',
-                'urgency': 'medium',
-                'repo-user': 'DEBIAN',
+                'qemubuilder': 'False',
+                'remote-config': '',
+                'remote-url-pattern': 'ssh://git.debian.org/git/collab-maint/%(pkg)s.git',
+                'renumber': 'False',
                 'repo-email': 'DEBIAN',
+                'repo-user': 'DEBIAN',
+                'rollback': 'True',
+                'sign-tags': 'False',
+                'snapshot-number': 'snapshot + 1',
+                'spawn-editor': 'release',
+                'submodules': 'False',
+                'symlink-orig': 'True',
+                'tarball-dir': '',
+                'template-dir': '',
+                'time-machine': 1,
+                'track': 'True',
+                'upstream-branch': 'upstream',
+                'upstream-tag': 'upstream/%(version)s',
+                'upstream-tree': 'TAG',
+                'upstream-vcs-tag': '',
+                'urgency': 'medium',
                 }
     help = {
         'debian-branch':
@@ -342,6 +344,8 @@ class GbpOptionParser(OptionParser):
         'drop':
             "In case of 'export' drop the patch-queue branch "
             "after export. Default is '%(drop)s'",
+        'abbrev':
+            "abbreviate commits to this length. default is '%(abbrev)s'",
         'commit':
             "commit changes after export, Default is '%(commit)s'",
         'rollback':
@@ -373,7 +377,7 @@ class GbpOptionParser(OptionParser):
                         ('%(top_dir)s/debian/gbp.conf', 'debian'),
                         ('%(git_dir)s/gbp.conf', None)]
 
-    list_opts = ['filter', 'component']
+    list_opts = ['filter', 'component', 'dch-opt']
 
     @classmethod
     def get_config_files(cls, no_local=False):
@@ -458,7 +462,7 @@ class GbpOptionParser(OptionParser):
         >>> GbpOptionParser._listify('[')
         Traceback (most recent call last):
         ...
-        Error: [ is not a proper list
+        configparser.Error: [ is not a proper list
         """
         # filter can be either a list or a string, always build a list:
         if value:
@@ -500,7 +504,7 @@ class GbpOptionParser(OptionParser):
         self.config = dict(self.__class__.defaults)
         config_files = self.get_config_files()
         try:
-            repo = GitRepository(".")
+            repo = GitRepository(".", toplevel=False)
         except GitRepositoryError:
             repo = None
         # Read all config files
@@ -664,10 +668,14 @@ class GbpOptionParser(OptionParser):
         """
         if file is None:
             file = sys.stdout
-        encoding = self._get_encoding(file)
+
+        encoding = file.encoding if hasattr(file, 'encoding') else 'utf-8'
         try:
-            file.write(self.format_help().encode(encoding, "replace"))
-        except IOError as e:
+            msg = self.format_help()
+            if hasattr(file, 'mode') and 'b' in file.mode:
+                msg = msg.encode(encoding, "replace")
+            file.write(msg)
+        except OSError as e:
             if e.errno != errno.EPIPE:
                 raise
 
