@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2011,2015 Guido Guenther <agx@sigxcpu.org>
+# (C) 2011,2015,2017 Guido Guenther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -63,22 +63,23 @@ class Patch(object):
         """
         self.info = {}
         body = tempfile.NamedTemporaryFile(prefix='gbp_')
-        pipe = subprocess.Popen("git mailinfo '%s' /dev/null 2>/dev/null < '%s'" %
+        pipe = subprocess.Popen("git mailinfo -k '%s' /dev/null 2>/dev/null < '%s'" %
                                 (body.name, self.path),
                                 shell=True,
                                 stdout=subprocess.PIPE).stdout
         for line in pipe:
+            line = line.decode()
             if ':' in line:
                 rfc_header, value = line.split(" ", 1)
                 header = rfc_header[:-1].lower()
                 self.info[header] = value.strip()
         try:
-            self.long_desc = "".join([line for line in body])
-            body.close()
-        except IOError as msg:
+            self.long_desc = "".join([l.decode("utf-8", "backslashreplace") for l in body])
+        except (IOError, UnicodeDecodeError) as msg:
             raise GbpError("Failed to read patch header of '%s': %s" %
-                           (self.patch, msg))
+                           (self.path, msg))
         finally:
+            body.close()
             if os.path.exists(body.name):
                 os.unlink(body.name)
 
@@ -167,7 +168,7 @@ class PatchSeries(list):
     level_re = re.compile('-p(?P<level>[0-9]+)')
 
     @classmethod
-    def read_series_file(klass, seriesfile):
+    def read_series_file(cls, seriesfile):
         """Read a series file into L{Patch} objects"""
         patch_dir = os.path.dirname(seriesfile)
 
@@ -179,12 +180,12 @@ class PatchSeries(list):
         except Exception as err:
             raise GbpError("Cannot open series file: %s" % err)
 
-        queue = klass._read_series(s, patch_dir)
+        queue = cls._read_series(s, patch_dir)
         s.close()
         return queue
 
     @classmethod
-    def _read_series(klass, series, patch_dir):
+    def _read_series(cls, series, patch_dir):
         """
         Read patch series
 
@@ -211,7 +212,7 @@ class PatchSeries(list):
                     continue
             except IndexError:
                 continue  # ignore empty lines
-            queue.append(klass._parse_line(line, patch_dir))
+            queue.append(cls._parse_line(line, patch_dir))
         return queue
 
     @staticmethod
@@ -230,7 +231,7 @@ class PatchSeries(list):
         return topic
 
     @classmethod
-    def _strip_comment(klass, line):
+    def _strip_comment(cls, line):
         """
         Strip a comment from a series file line
 
@@ -241,10 +242,10 @@ class PatchSeries(list):
         >>> PatchSeries._strip_comment("leave/level/intact -p1 # comment # text")
         'leave/level/intact -p1'
         """
-        return re.sub(klass.comment_re, '', line)
+        return re.sub(cls.comment_re, '', line)
 
     @classmethod
-    def _split_strip(klass, line):
+    def _split_strip(cls, line):
         """
         Separate the -p<num> option from the patch name
 
@@ -260,7 +261,7 @@ class PatchSeries(list):
 
         split = line.rsplit(None, 1)
         if len(split) > 1:
-            m = klass.level_re.match(split[1])
+            m = cls.level_re.match(split[1])
             if m:
                 patch = split[0]
                 strip = int(m.group('level'))
@@ -268,7 +269,7 @@ class PatchSeries(list):
         return (patch, strip)
 
     @classmethod
-    def _parse_line(klass, line, patch_dir):
+    def _parse_line(cls, line, patch_dir):
         """
         Parse a single line from a series file
 
@@ -277,7 +278,7 @@ class PatchSeries(list):
         >>> PatchSeries._parse_line("a/b", '.')
         <gbp.patch_series.Patch path='./a/b' topic='a' >
         """
-        line = klass._strip_comment(line.rstrip())
-        topic = klass._get_topic(line)
-        (patch, split) = klass._split_strip(line)
+        line = cls._strip_comment(line.rstrip())
+        topic = cls._get_topic(line)
+        (patch, split) = cls._split_strip(line)
         return Patch(os.path.join(patch_dir, patch), topic, split)
