@@ -32,7 +32,7 @@ from gbp.deb.git import (GitRepositoryError, DebianGitRepository)
 from gbp.deb.source import DebianSource, DebianSourceError, FileVfs
 from gbp.deb.format import DebianSourceFormat
 from gbp.git.vfs import GitVfs
-from gbp.deb.upstreamsource import DebianUpstreamSource
+from gbp.deb.upstreamsource import DebianUpstreamSource, unpack_component_tarball
 from gbp.errors import GbpError
 import gbp.log
 import gbp.notifications
@@ -42,23 +42,10 @@ from gbp.scripts.common.buildpackage import (index_name, wc_name,
 from gbp.scripts.common import ExitCodes
 from gbp.scripts.common.hook import Hook
 
-from gbp.scripts.export_orig import prepare_upstream_tarballs
+from gbp.scripts.export_orig import prepare_upstream_tarballs, guess_comp_type
 from gbp.scripts.tag import perform_tagging
 
 
-def pristine_tar_commit(repo, source, options, output_dir, orig_file, upstream_tree):
-    if repo.pristine_tar.has_commit(source.name,
-                                    source.upstream_version,
-                                    options.comp_type):
-        gbp.log.debug("%s already on pristine tar branch" %
-                      orig_file)
-    else:
-        archive = os.path.join(output_dir, orig_file)
-        gbp.log.debug("Adding %s to pristine-tar branch" %
-                      archive)
-        repo.pristine_tar.commit(archive, upstream_tree)
-
-
 # Functions to handle export-dir
 def maybe_write_tree(repo, options):
     """
@@ -99,10 +86,7 @@ def export_source(repo, tree, source, options, dest_dir, tarball_dir):
     if options.overlay:
         if source.is_native():
             raise GbpError("Cannot overlay Debian native package")
-        extract_orig(os.path.join(tarball_dir,
-                                  source.upstream_tarball_name(
-                                      options.comp_type)),
-                     dest_dir)
+        overlay_extract_origs(source, tarball_dir, dest_dir, options)
 
     gbp.log.info("Exporting '%s' to '%s'" % (options.export, dest_dir))
     if not dump_tree(repo, dest_dir, tree, options.with_submodules):
@@ -118,12 +102,18 @@ def move_old_export(target):
             os.rename(target, "%s.obsolete.%s" % (target, time.time()))
 
 
-def extract_orig(orig_tarball, dest_dir):
-    """extract orig tarball to export dir before exporting from git"""
-    gbp.log.info("Extracting %s to '%s'" % (os.path.basename(orig_tarball), dest_dir))
+def overlay_extract_origs(source, tarball_dir, dest_dir, options):
+    """Overlay extract orig tarballs to export dir before exporting debian dir from git"""
+
+    comp_type = guess_comp_type(options.comp_type,
+                                source,
+                                repo=None,
+                                tarball_dir=tarball_dir)
+    tarball = os.path.join(tarball_dir, source.upstream_tarball_name(comp_type))
+    gbp.log.info("Extracting %s to '%s'" % (os.path.basename(tarball), dest_dir))
 
     move_old_export(dest_dir)
-    upstream = DebianUpstreamSource(orig_tarball)
+    upstream = DebianUpstreamSource(tarball)
     upstream.unpack(dest_dir)
 
     # Check if tarball extracts into a single folder:
@@ -145,6 +135,13 @@ def extract_orig(orig_tarball, dest_dir):
                          "source at %s" % underlay_debian_dir)
             shutil.rmtree(underlay_debian_dir)
 
+    # Unpack additional tarballs
+    for c in options.components:
+        tarball = os.path.join(tarball_dir, source.upstream_tarball_name(
+            comp_type, component=c))
+        gbp.log.info("Unpacking '%s' to '%s'" % (os.path.basename(tarball), dest_dir))
+        unpack_component_tarball(dest_dir, c, tarball, [])
+
 
 def source_vfs(repo, options, tree):
     """Init source package info either from git or from working copy"""
