@@ -30,24 +30,26 @@ from gbp.deb import compare_versions
 from gbp.deb.source import DebianSource, DebianSourceError
 from gbp.deb.git import GitRepositoryError, DebianGitRepository
 from gbp.deb.changelog import ChangeLog, NoChangeLogError
-from gbp.scripts.common import ExitCodes
+from gbp.scripts.common import ExitCodes, maybe_debug_raise
 
 user_customizations = {}
 snapshot_re = re.compile("\s*\*\* SNAPSHOT build @(?P<commit>[a-z0-9]+)\s+\*\*")
 
 
-def guess_version_from_upstream(repo, upstream_tag_format, upstream_branch, cp):
+def guess_version_from_upstream(repo, upstream_tag_format, upstream_branch, cp=None):
     """
     Guess the version based on the latest version on the upstream branch.
     If the version in dch is already higher this function returns None.
     """
+    epoch = cp.epoch if cp else None
+    cmp_version = cp.version if cp else '0~'
     try:
         version = repo.debian_version_from_upstream(upstream_tag_format,
                                                     upstream_branch,
-                                                    epoch=cp.epoch,
+                                                    epoch=epoch,
                                                     debian_release=False)
         gbp.log.debug("Found upstream version %s." % version)
-        if compare_versions(version, cp.version) > 0:
+        if compare_versions(version, cmp_version) > 0:
             return "%s-1" % version
     except GitRepositoryError as e:
         gbp.log.debug("No upstream tag found: %s" % e)
@@ -302,6 +304,26 @@ def changelog_commit_msg(options, version):
     return options.commit_msg % dict(version=version)
 
 
+def create_changelog(repo, source, options):
+    try:
+        name = source.control.name
+    except DebianSourceError:
+        raise GbpError("Did not find debian/changelog or debian/source. Is this a Debian package?")
+    version = guess_version_from_upstream(repo, options.upstream_tag,
+                                          options.upstream_branch, None)
+    return ChangeLog.create(name, version)
+
+
+def maybe_create_changelog(repo, source, options):
+    """
+    Get the changelog or create a new one if it does not exist yet
+    """
+    try:
+        return source.changelog
+    except DebianSourceError:
+        return create_changelog(repo, source, options)
+
+
 def build_parser(name):
     try:
         parser = GbpOptionParserDebian(command=os.path.basename(name),
@@ -450,7 +472,7 @@ def main(argv):
             raise GbpError("Use --ignore-branch to ignore or --debian-branch to set the branch name.")
 
         source = DebianSource('.')
-        cp = source.changelog
+        cp = maybe_create_changelog(repo, source, options)
 
         if options.since:
             since = options.since
@@ -570,6 +592,7 @@ def main(argv):
         if str(err):
             gbp.log.err(err)
         ret = 1
+        maybe_debug_raise()
     finally:
         os.chdir(old_cwd)
     return ret
