@@ -24,8 +24,8 @@ import glob
 import time
 import shutil
 import errno
-from six.moves.urllib.request import urlopen
-from six.moves import urllib
+from urllib.request import urlopen
+import urllib
 
 import gbp.command_wrappers as gbpc
 from gbp.tmpfile import init_tmpdir, del_tmpdir, tempfile
@@ -39,7 +39,7 @@ from gbp.errors import GbpError
 from gbp.scripts.common import ExitCodes, is_download
 from gbp.scripts.common import repo_setup
 import gbp.log
-from gbp.pkg import parse_archive_filename
+from gbp.pkg import Archive
 
 no_packaging_branch_msg = """
 Repository does not have branch '%s' for packaging/distribution sources.
@@ -181,7 +181,7 @@ def build_parser(name):
                                                 dest="pristine_tar")
     import_group.add_option("--allow-same-version", action="store_true",
                             dest="allow_same_version", default=False,
-                            help="allow to import already imported version")
+                            help="allow import of already imported version")
     import_group.add_boolean_config_file_option(
         option_name="author-is-committer",
         dest="author_is_committer")
@@ -400,7 +400,7 @@ def main(argv):
 
                 if not options.native:
                     if options.pristine_tar:
-                        archive_fmt = parse_archive_filename(orig_tarball)[1]
+                        archive_fmt = Archive.parse_filename(orig_tarball)[1]
                         if archive_fmt == 'tar':
                             repo.pristine_tar.commit(orig_tarball,
                                                      'refs/heads/%s' %
