@@ -54,12 +54,15 @@ def mock_gbp(args):
 
 def mock_notify(summary, message, notify_opt):
     """Mock notification system"""
+    if notify_opt.is_off():
+        return True
     # Auto will succeed
-    if notify_opt.is_auto():
+    elif notify_opt.is_auto():
         MOCK_NOTIFICATIONS.append((summary, message))
         return True
     # Otherwise fail
-    return False
+    else:
+        return False
 
 
 class TestGbpRpm(RpmRepoTestBase):
@@ -247,7 +250,7 @@ class TestGbpRpm(RpmRepoTestBase):
         # Dummy update to upstream branch
         pkg_branch = repo.get_branch()
         upstr_branch = 'upstream'
-        orig_files = ['gbp-test/' + path for
+        orig_files = ['gbp-test/' + path.decode() for
                       path in repo.ls_tree(upstr_branch)] + ['gbp-test']
         repo.set_branch(upstr_branch)
         for fname in ['new-file', 'new-file2']:
@@ -369,7 +372,7 @@ class TestGbpRpm(RpmRepoTestBase):
         repo.set_branch(pkg_branch)
 
         sub_files = sub_repo.ls_tree('HEAD')
-        upstr_files = ['gbp-test/' + path for
+        upstr_files = ['gbp-test/' + path.decode() for
                        path in repo.ls_tree(upstr_branch)]
 
         # Test the "no" option
@@ -383,7 +386,7 @@ class TestGbpRpm(RpmRepoTestBase):
         eq_(mock_gbp(['--git-submodules', '--git-upstream-tree=%s' %
                       upstr_branch, '--git-ignore-new']), 0)
         tar_files = ls_tar('../rpmbuild/SOURCES/gbp-test-1.1.tar.bz2', False)
-        ref_files = upstr_files + ['gbp-test/gbp-test-native.repo/' + path for
+        ref_files = upstr_files + ['gbp-test/gbp-test-native.repo/' + path.decode() for
                                    path in sub_files]
         self.check_files(ref_files, tar_files)
         shutil.rmtree('../rpmbuild')
@@ -408,13 +411,13 @@ class TestGbpRpm(RpmRepoTestBase):
         repo.commit_all('Add submodule')
 
         sub_files = sub_repo.ls_tree('HEAD')
-        master_files = ['gbp-test-native-1.0/' + path for
+        master_files = ['gbp-test-native-1.0/' + path.decode() for
                         path in repo.ls_tree('HEAD')]
 
         # Test
         eq_(mock_gbp(['--git-submodules']), 0)
         zip_files = ls_zip('../rpmbuild/SOURCES/gbp-test-native-1.0.zip', False)
-        ref_files = master_files + ['gbp-test-native-1.0/gbp-test-native2.repo/' + path for
+        ref_files = master_files + ['gbp-test-native-1.0/gbp-test-native2.repo/' + path.decode() for
                                     path in sub_files]
         self.check_files(ref_files, zip_files)
 
@@ -531,7 +534,7 @@ class TestGbpRpm(RpmRepoTestBase):
             eq_(mock_gbp(['--git-builder=true']), 1)
         finally:
             os.chmod('../rpmbuild/SOURCES/gbp-test-native-1.0.zip', s_rwx)
-        self._check_log(-1, ".*Error creating ../rpmbuild/SOURCES/.*.zip")
+        self._check_log(-1, ".*Cannot create source tarball at '../rpmbuild/SOURCES'")
 
     def test_option_export(self):
         """Test the --git-export-option"""
@@ -556,7 +559,7 @@ class TestGbpRpm(RpmRepoTestBase):
 
         base_args = ['--git-ignore-new', '--git-builder=true']
         # Test exporting of git index
-        foo_txt_index = repo.show('HEAD:foo.txt') + 'staged'
+        foo_txt_index = repo.show('HEAD:foo.txt').decode() + 'staged'
         eq_(mock_gbp(base_args + ['--git-export=INDEX']), 0)
         self.check_and_rm_file('../rpmbuild/SOURCES/foo.txt', foo_txt_index)
         ok_(not os.path.exists('../rpmbuild/SOURCES/untracked'))
@@ -565,7 +568,7 @@ class TestGbpRpm(RpmRepoTestBase):
 
         # Test exporting of working copy (include all files)
         eq_(mock_gbp(base_args + ['--git-export=WC']), 0)
-        foo_txt_wc = repo.show('HEAD:foo.txt') + 'staged' + 'unstaged'
+        foo_txt_wc = repo.show('HEAD:foo.txt').decode() + 'staged' + 'unstaged'
         self.check_and_rm_file('../rpmbuild/SOURCES/foo.txt', foo_txt_wc)
         self.check_and_rm_file('../rpmbuild/SOURCES/untracked', 'untracked')
         self.check_and_rm_file('../rpmbuild/SOURCES/ignored.tmp', 'ignored')
